==> mediawiki-1.13.3.tar.gz: mediawiki-1.13.3/languages/messages/MessagesZu.php <==
<?php
/** Zulu (isiZulu)
 *
 * @ingroup Language
 * @file
 *
 * @author לערי ריינהארט
 */

$messages = array(
'underline-always' => 'Njalo',

# Dates
'sunday'    => 'iSonto',
'monday'    => 'uMsombuluko',
'tuesday'   => 'uLwesibili',
'wednesday' => 'uLwesithathu',
'thursday'  => 'uLwesine',
'friday'    => 'uLwesihlanu',
'saturday'  => 'uMgqibelo',
'january'   => 'uJanuwali',
'february'  => 'uFebruwari',
'march'     => 'uMashi',
'april'     => 'u-Apreli',
'may_long'  => 'uMeyi',
'june'      => 'uJuni',
'july'      => 'uJulayi',
'august'    => 'u-Agasti',
'september' => 'uSepthemba',
'october'   => 'u-Okthoba',
'november'  => 'uNovemba',
'december'  => 'uDisemba',
'may'       => 'uMeyi',

'cancel'        => 'Nqamula',
'qbfind'        => 'Thola',
'qbbrowse'      => 'Cinga',
'qbedit'        => 'Ukuhlela',
'qbpageoptions' => 'Leli khasi',
'qbmyoptions'   => 'Amakhasi ami',
'moredotdotdot' => 'Amanye...',
'mypage'        => 'Ikhasi lami',
'mytalk'        => 'Ingxoxo yami',
'navigation'    => 'Ukuqondiswa kwemikhumbi',

'errorpagetitle'   => 'Icala',
'help'             => 'Usizo',
'search'           => 'Sesha',
'searchbutton'     => 'Sesha',
'go'               => 'Hamba',
'history_short'    => 'Umlando',
'printableversion' => 'Inguqulo eshicilelekayo',
'print'            => 'Shicilela',
'edit'             => 'Hlela',
'editthispage'     => 'Hlela leli khasi',
'delete'           => 'Sula',
'deletethispage'   => 'Sula lelikhasi',
'protect'          => 'Londoloza',
'protectthispage'  => 'Londoloza lelikhasi',
'newpage'          => 'Ikhasi elisha',
'talkpage'         => 'Xoxa ngalelikhasi',
'personaltools'    => 'Amathuluzi kamsebenzisi',
'talk'             => 'Ingxoxo',
'toolbox'          => 'Amathuluzi',
'otherlanguages'   => 'Ngezilimi ezinahlukene',
'redirectpagesub'  => 'Ikhasi likakuphambukisa',
'protectedpage'    => 'Ikhasi elilondolozwa',
'jumpto'           => 'Eqa e:',
'jumptonavigation' => 'Ukuqondiswa kwemikhumbi',
'jumptosearch'     => 'Sesha',

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
'currentevents'        => 'Izehlakalo ezimanje',
'currentevents-url'    => 'Project:Izehlakalo ezimanje',
'edithelp'             => 'Usizo ngokuhlela',
'helppage'             => 'Help:Isiqikili',
'mainpage'             => 'Ikhasi Elikhulu',
'mainpage-description' => 'Ikhasi Elikhulu',
'portal'               => 'Umnyango wamgwamanda',
'portal-url'           => 'Project:Umnyango wamgwamanda',

'newmessageslink'         => 'Imilayezo emisha',
'youhavenewmessagesmulti' => 'Uyanemilayezo emisha e $1',
'toc'                     => 'Isiqikili',
'showtoc'                 => 'Bukisa',
'hidetoc'                 => 'Fihla',

# Short words for each namespace, by default used in the namespace tab in monobook
'nstab-main'      => 'Umlayezo',
'nstab-user'      => 'Ikhasi lomsebenzisi',
'nstab-special'   => 'Kukhulu',
'nstab-image'     => 'Ifayela',
'nstab-mediawiki' => 'Umlayezo',
'nstab-help'      => 'Usizo',
'nstab-category'  => 'Uhlobo',

# General errors
'error'         => 'Icala',
'databaseerror' => 'Idatabheyisi linecala',
'internalerror' => 'Icala lingaphakathi',

# Login and logout pages
'welcomecreation'    => '== Umbingelelo, $1! ==

ikhawundi lakho liyadalwa. musa ukukhohlwa ukuguqula amakhethelo a-{{SITENAME}} wakho.',
'yourname'           => 'Isiga',
'yourpassword'       => 'Izwi elingenangozi',
'yourpasswordagain'  => 'Bhala izwi elingenangozi lakho kabusha',
'remembermypassword' => 'Ngikhumbule',
'login'              => 'Ngena',
'userlogin'          => 'Ngena / Dala ikhawundi',
'logout'             => 'Phuma',
'userlogout'         => 'Phuma',
'notloggedin'        => 'Awungenile',
'nologin'            => 'Awunekhawundi? $1.',
'nologinlink'        => 'Dala ikhawundi',
'createaccount'      => 'Dala ikhawundi',
'gotaccountlink'     => 'Ngena',
'username'           => 'Isiga:',
'yourrealname'       => 'Igama eliqinisileyo',
'yourlanguage'       => 'Ulimi:',
'email'              => 'Iposi likagesi',
'loginsuccesstitle'  => 'Ubengena',
'nosuchuser'         => 'Akukho umsebenzisi unegama "$1". Hlola umbhalo wakho, noma dala ikhawundi elisha.',
'nosuchusershort'    => 'Akukho umsebenzisi unegama "<nowiki>$1</nowiki>". Hlola umbhalo wakho.',
'emailconfirmlink'   => 'Qinisekisa ikheli likagesi lakho',
'loginlanguagelabel' => 'Ulimi: $1',

# Edit page toolbar
'italic_sample' => 'Amazwi ama-italiki',
'italic_tip'    => 'Amazwi ama-italiki',
'math_sample'   => 'Faka izibalo lapha',
'hr_tip'        => 'Umugqa uhleliwe  (use sparingly)',

# Edit pages
'summary'            => 'Isifinyezo',
'minoredit'          => 'Lokho ngukuhlela okuncane',
'watchthis'          => 'Bukela ngalelikhasi',
'savearticle'        => 'Ukonga ikhasi',
'preview'            => 'Isibonakalo',
'showpreview'        => 'Bukisa isibonakalo',
'showdiff'           => 'Bukisa izinguquko',
'missingcommenttext' => 'Ake ubhale uvo ngaphansi.',
'loginreqtitle'      => 'Lidinga ukuthi uyangena',
'loginreqlink'       => 'Ngena',
'noarticletext'      => 'Akukho umbhalo kuleli khasi manje. Unga [[Special:Search/Allmessages|cinga leli bizo lekhasi]] emakhasini amanye noma unga [{{fullurl:{{FULLPAGENAME}}|action=edit}} hlela leli khasi].',
'yourtext'           => 'Umbhalo wakho',
'yourdiff'           => 'Izinguquko',

# History pages
'next'      => 'Kulandela',
'last'      => 'Amagcino',
'histfirst' => 'lokuqala',
'histlast'  => 'ligcinileyo',

# Revision deletion
'rev-delundel' => 'bukisa/fihla',

# Search results
'searchresults' => 'Umphumela wokusesha',
'powersearch'   => 'Sesha',

# Preferences page
'preferences'       => 'Amakhethelo',
'mypreferences'     => 'Amakhethelo ami',
'prefsnologin'      => 'Awungenile',
'qbsettings'        => 'Imeniyu',
'changepassword'    => 'Guqula izwi elingenangozi',
'math'              => 'Izibalo',
'saveprefs'         => 'Saveprefs',
'newpassword'       => 'Izwi elingenangozi elisha:',
'searchresultshead' => 'Sesha',
'timezonelegend'    => 'Isifunda sasikhathi',
'localtime'         => 'Isikhathi siyalapha',

# Recent changes
'recentchanges' => 'Izinguquko ezimanje',
'hide'          => 'Fihla',
'show'          => 'Bukisa',

# Recent changes linked
'recentchangeslinked' => 'Izinguquko ezilandiweyo',

# Upload
'upload'           => 'Layisha ifayili',
'uploadbtn'        => 'Layisha ifayili',
'filesource'       => 'Umthombo:',
'ignorewarnings'   => 'Duba imiyalo',
'successfulupload' => 'Ukulayisha okuchumile',

'nolicense' => 'Ubekhetha lutho',

# Image description page
'nolinkstoimage'   => 'Akukho amakhasi akhomba kuleli fayela.',
'noimage'          => 'Akukho ifayela elinaleli gama, unga $1.',
'noimage-linktext' => 'Layisha',

# Random page
'randompage' => 'Ikhasi elingaphandle kokucabanga',

# Statistics
'userstats' => 'Ukwaziswa wamsebenzisi',

# Miscellaneous special pages
'shortpages'        => 'Amakhasi amafishane',
'longpages'         => 'Amakhasi amade',
'newpages'          => 'Amakhasi amasha',
'newpages-username' => 'Isiga:',
'move'              => 'Sunduza',
'movethispage'      => 'Thuthisa leli khasi',

# Special:Log
'specialloguserlabel' => 'Umsebenzisi:',

# Special:AllPages
'allinnamespace' => 'Onke amakhasi ($1 namespace)',
'allpagessubmit' => 'Hamba',

# E-mail user
'emailuser'    => 'Thumela umlayezo lo msebenzisi',
'noemailtitle' => 'Akukho ikheli likaposi',
'emailsubject' => 'Indaba',
'emailmessage' => 'Umlayezo',
'emailsend'    => 'Thuma',
'emailsent'    => 'Umlayezo uthumwa',

# Watchlist
'watchlist'    => 'Uhlelo ubukelwa wami',
'watch'        => 'Bukela',
'unwatch'      => "Mus'ukubukela",
'notanarticle' => 'Akulona ikhasi elinakho okuqukethwe',

'enotif_newpagetext' => 'Lelikhasi liyasha.',

# Delete/protect/revert
'deletepage'     => 'Sula ikhasi',
'confirm'        => 'Qinisekisa',
'exblank'        => 'ikhasi elize',
'protectcomment' => 'Isizathu ngenxa yalondoloza',

# Restrictions (nouns)
'restriction-edit' => 'Ukuhlela',
'restriction-move' => 'Sunduza',

# Undelete
'undeletecomment' => 'Khuluma:',

# Contributions
'contributions' => 'Amanikelo amsebenzisi',
'mycontris'     => 'Amanikelo ami',

# What links here
'isredirect' => 'Ikhasi silayela',

# Block/unblock
'blockip'            => 'Vimbela lo msebenzisi',
'ipbexpiry'          => 'Ukuphela',
'ipbreason'          => 'Isizathu',
'ipbsubmit'          => 'Vimbela lo msebenzisi',
'ipusubmit'          => 'Qeda isivimbelo lo msebenzisi',
'createaccountblock' => 'Ukudala kwekhawundi kuvimbelwa',
'proxyblocksuccess'  => 'Kuphelile.',

# Developer tools
'databasenotlocked' => 'Idatabheyisi alikhiyiwi.',

# Move page
'move-page-legend'        => 'Thuthisa ikhasi',
'movearticle'             => 'Thuthisa ikhasi',
'movepagebtn'             => 'Thuthisa ikhasi',
'movedto'                 => 'Lithuthiselwe e',
'movereason'              => 'Isizathu',
'delete_and_move'         => 'Sula futhi sunduza',
'delete_and_move_confirm' => 'Yebo, sula ikhasi',

# Export
'export-submit' => 'Thekelisa',

# Namespace 8 related
'allmessagesname' => 'Igama',

# Thumbnails
'thumbnail-more' => 'Khulisa',
'filemissing'    => 'Ifayili lilahlekile',

# Special:Import
'import-interwiki-submit' => 'Ngenisa',

# Attribution
'others' => 'Abanye',

# Patrolling
'markaspatrolleddiff' => 'Dweba ukuthi lelikhasi liyagadwa',
'markaspatrolledtext' => 'Dweba ukuthi lelikhasi liyagadwa',
'markedaspatrolled'   => 'Dweba ukuthi lelikhasi liyagadwa',

# Special:NewImages
'newimages' => 'Uhlelo lwamafayela amasha',
'noimages'  => 'Awuboni lutho.',
'ilsubmit'  => 'Sesha',

# Metadata
'metadata-expand'   => 'Bukisa imininingwane yonke',
'metadata-collapse' => 'Fihla imininingwane yonke',

# EXIF tags
'exif-orientation' => 'Ukuma okumaqondana nempumalanga',
'exif-artist'      => 'Umbhali',
'exif-sharpness'   => 'Ububukhali',

'exif-orientation-1' => 'Kuphelele', # 0th row: top; 0th column: left

'exif-meteringmode-5' => 'Umhlobiso',

'exif-lightsource-4'  => 'Umbani',
'exif-lightsource-11' => 'Umthunzi',

'exif-sensingmethod-1' => 'Akucaci',

'exif-scenecapturetype-0' => 'Izinga',
'exif-scenecapturetype-1' => 'Umfanekiso wesizwe',
'exif-scenecapturetype-2' => 'Umfanekiso womuntu',
'exif-scenecapturetype-3' => 'Imboniso ebusuku',

'exif-contrast-0' => 'Kuphelele',
'exif-contrast-1' => 'Kuntofontofo',
'exif-contrast-2' => 'Kulukhuni',

'exif-saturation-0' => 'Kuphelele',

'exif-sharpness-0' => 'Kuphelele',
'exif-sharpness-1' => 'Kuntofontofo',
'exif-sharpness-2' => 'Kulukhuni',

# 'all' in various places, this might be different for inflected languages
'recentchangesall' => 'Konke',

# E-mail address confirmation
'confirmemail'          => 'Qinisekisa ikheli likagesi',
'confirmemail_loggedin' => 'Ikheli likagesi lakho liqinisekiswa.',

# Delete conflict
'recreate' => 'Dala kabusha',

# action=purge
'confirm_purge_button' => 'Kulungile',

# Special:FilePath
'filepath-submit' => 'Indlela',

);

==> mediawiki-1.17.2.tar.gz: mediawiki-1.17.2/languages/messages/MessagesZu.php <==
<?php
/** Zulu (isiZulu)
 *
 * See MessagesQqq.php for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author לערי ריינהארט
 */

$messages = array(
'underline-always' => 'Njalo',

# Dates
'sunday'        => 'iSonto',
'monday'        => 'uMsombuluko',
'tuesday'       => 'uLwesibili',
'wednesday'     => 'uLwesithathu',
'thursday'      => 'uLwesine',
'friday'        => 'uLwesihlanu',
'saturday'      => 'uMgqibelo',
'january'       => 'uJanuwali',
'february'      => 'uFebruwari',
'march'         => 'uMashi',
'april'         => 'u-Apreli',
'may_long'      => 'uMeyi',
'june'          => 'uJuni',
'july'          => 'uJulayi',
'august'        => 'u-Agasti',
'september'     => 'uSepthemba',
'october'       => 'u-Okthoba',
'november'      => 'uNovemba',
'december'      => 'uDisemba',
'january-gen'   => 'uJanuwali',
'february-gen'  => 'uFebruwari',
'march-gen'     => 'uMashi',
'april-gen'     => 'u-Apreli',
'may-gen'       => 'uMeyi',
'june-gen'      => 'uJuni',
'july-gen'      => 'uJulayi',
'august-gen'    => 'u-Agasti',
'september-gen' => 'uSepthemba',
'october-gen'   => 'u-Okthoba',
'november-gen'  => 'uNovemba',
'december-gen'  => 'uDisemba',
'may'           => 'uMeyi',

'cancel'        => 'Nqamula',
'moredotdotdot' => 'Amanye...',
'mypage'        => 'Ikhasi lami',
'mytalk'        => 'Ingxoxo yami',
'navigation'    => 'Ukuqondiswa kwemikhumbi',

# Cologne Blue skin
'qbfind'        => 'Thola',
'qbbrowse'      => 'Cinga',
'qbedit'        => 'Ukuhlela',
'qbpageoptions' => 'Leli khasi',
'qbmyoptions'   => 'Amakhasi ami',

'errorpagetitle'   => 'Icala',
'help'             => 'Usizo',
'search'           => 'Sesha',
'searchbutton'     => 'Sesha',
'go'               => 'Hamba',
'searcharticle'    => 'Hamba',
'history_short'    => 'Umlando',
'printableversion' => 'Inguqulo eshicilelekayo',
'print'            => 'Shicilela',
'edit'             => 'Hlela',
'editthispage'     => 'Hlela leli khasi',
'delete'           => 'Sula',
'deletethispage'   => 'Sula lelikhasi',
'protect'          => 'Londoloza',
'protectthispage'  => 'Londoloza lelikhasi',
'newpage'          => 'Ikhasi elisha',
'talkpage'         => 'Xoxa ngalelikhasi',
'personaltools'    => 'Amathuluzi kamsebenzisi',
'talk'             => 'Ingxoxo',
'toolbox'          => 'Amathuluzi',
'otherlanguages'   => 'Ngezilimi ezinahlukene',
'redirectpagesub'  => 'Ikhasi likakuphambukisa',
'protectedpage'    => 'Ikhasi elilondolozwa',
'jumpto'           => 'Eqa e:',
'jumptonavigation' => 'Ukuqondiswa kwemikhumbi',
'jumptosearch'     => 'Sesha',

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
'currentevents'        => 'Izehlakalo ezimanje',
'currentevents-url'    => 'Project:Izehlakalo ezimanje',
'edithelp'             => 'Usizo ngokuhlela',
'helppage'             => 'Help:Isiqikili',
'mainpage'             => 'Ikhasi Elikhulu',
'mainpage-description' => 'Ikhasi Elikhulu',
'portal'               => 'Umnyango wamgwamanda',
'portal-url'           => 'Project:Umnyango wamgwamanda',

'newmessageslink'         => 'Imilayezo emisha',
'youhavenewmessagesmulti' => 'Uyanemilayezo emisha e $1',
'editsection'             => 'hlela',
'toc'                     => 'Isiqikili',
'showtoc'                 => 'Bukisa',
'hidetoc'                 => 'Fihla',

# Short words for each namespace, by default used in the namespace tab in monobook
'nstab-main'      => 'Umlayezo',
'nstab-user'      => 'Ikhasi lomsebenzisi',
'nstab-special'   => 'Kukhulu',
'nstab-image'     => 'Ifayela',
'nstab-mediawiki' => 'Umlayezo',
'nstab-help'      => 'Usizo',
'nstab-category'  => 'Uhlobo',

# General errors
'error'         => 'Icala',
'databaseerror' => 'Idatabheyisi linecala',
'internalerror' => 'Icala lingaphakathi',

# Login and logout pages
'welcomecreation'         => '== Umbingelelo, $1! ==

ikhawundi lakho liyadalwa. musa ukukhohlwa ukuguqula amakhethelo a-{{SITENAME}} wakho.',
'yourname'                => 'Isiga',
'yourpassword'            => 'Izwi elingenangozi',
'yourpasswordagain'       => 'Bhala izwi elingenangozi lakho kabusha',
'remembermypassword'      => 'Ngikhumbule (for a maximum of $1 {{PLURAL:$1|day|days}})',
'login'                   => 'Ngena',
'nav-login-createaccount' => 'Ngena / Dala ikhawundi',
'userlogin'               => 'Ngena / Dala ikhawundi',
'logout'                  => 'Phuma',
'userlogout'              => 'Phuma',
'notloggedin'             => 'Awungenile',
'nologin'                 => "Awunekhawundi? '''$1'''.",
'nologinlink'             => 'Dala ikhawundi',
'createaccount'           => 'Dala ikhawundi',
'gotaccountlink'          => 'Ngena',
'loginsuccesstitle'       => 'Ubengena',
'nosuchuser'              => 'Akukho umsebenzisi unegama "$1". Hlola umbhalo wakho, noma dala ikhawundi elisha.',
'nosuchusershort'         => 'Akukho umsebenzisi unegama "<nowiki>$1</nowiki>". Hlola umbhalo wakho.',
'emailconfirmlink'        => 'Qinisekisa ikheli likagesi lakho',
'loginlanguagelabel'      => 'Ulimi: $1',

# Password reset dialog
'newpassword' => 'Izwi elingenangozi elisha:',

# Edit page toolbar
'italic_sample' => 'Amazwi ama-italiki',
'italic_tip'    => 'Amazwi ama-italiki',
'math_sample'   => 'Faka izibalo lapha',
'hr_tip'        => 'Umugqa uhleliwe  (use sparingly)',

# Edit pages
'summary'            => 'Isifinyezo:',
'minoredit'          => 'Lokho ngukuhlela okuncane',
'watchthis'          => 'Bukela ngalelikhasi',
'savearticle'        => 'Ukonga ikhasi',
'preview'            => 'Isibonakalo',
'showpreview'        => 'Bukisa isibonakalo',
'showdiff'           => 'Bukisa izinguquko',
'missingcommenttext' => 'Ake ubhale uvo ngaphansi.',
'loginreqtitle'      => 'Lidinga ukuthi uyangena',
'loginreqlink'       => 'Ngena',
'noarticletext'      => 'Akukho umbhalo kuleli khasi manje. Unga [[Special:Search/Allmessages|cinga leli bizo lekhasi]] emakhasini amanye noma unga [{{fullurl:{{FULLPAGENAME}}|action=edit}} hlela leli khasi].',
'yourtext'           => 'Umbhalo wakho',
'yourdiff'           => 'Izinguquko',

# History pages
'next'      => 'Kulandela',
'last'      => 'Amagcino',
'histfirst' => 'lokuqala',
'histlast'  => 'ligcinileyo',

# Revision deletion
'rev-delundel' => 'bukisa/fihla',

# Search results
'searchresults'  => 'Umphumela wokusesha',
'searchhelp-url' => 'Help:Isiqikili',
'powersearch'    => 'Sesha',

# Quickbar
'qbsettings' => 'Imeniyu',

# Preferences page
'preferences'       => 'Amakhethelo',
'mypreferences'     => 'Amakhethelo ami',
'prefsnologin'      => 'Awungenile',
'changepassword'    => 'Guqula izwi elingenangozi',
'prefs-math'        => 'Izibalo',
'saveprefs'         => 'Saveprefs',
'searchresultshead' => 'Sesha',
'timezonelegend'    => 'Isifunda sasikhathi',
'localtime'         => 'Isikhathi siyalapha',
'username'          => 'Isiga:',
'yourrealname'      => 'Igama eliqinisileyo',
'yourlanguage'      => 'Ulimi:',
'email'             => 'Iposi likagesi',

# Recent changes
'recentchanges' => 'Izinguquko ezimanje',
'hide'          => 'Fihla',
'show'          => 'Bukisa',

# Recent changes linked
'recentchangeslinked'         => 'Izinguquko ezilandiweyo',
'recentchangeslinked-feed'    => 'Izinguquko ezilandiweyo',
'recentchangeslinked-toolbox' => 'Izinguquko ezilandiweyo',

# Upload
'upload'              => 'Layisha ifayili',
'uploadbtn'           => 'Layisha ifayili',
'filesource'          => 'Umthombo:',
'ignorewarnings'      => 'Duba imiyalo',
'upload-success-subj' => 'Ukulayisha okuchumile',

'nolicense' => 'Ubekhetha lutho',

# File description page
'file-anchor-link' => 'Ifayela',
'nolinkstoimage'   => 'Akukho amakhasi akhomba kuleli fayela.',

# Random page
'randompage' => 'Ikhasi elingaphandle kokucabanga',

# Statistics
'statistics-header-users' => 'Ukwaziswa wamsebenzisi',

# Miscellaneous special pages
'shortpages'        => 'Amakhasi amafishane',
'longpages'         => 'Amakhasi amade',
'newpages'          => 'Amakhasi amasha',
'newpages-username' => 'Isiga:',
'move'              => 'Sunduza',
'movethispage'      => 'Thuthisa leli khasi',

# Special:Log
'specialloguserlabel' => 'Umsebenzisi:',

# Special:AllPages
'allinnamespace' => 'Onke amakhasi ($1 namespace)',
'allpagessubmit' => 'Hamba',

# Special:Log/newusers
'newuserlog-create-entry' => 'Umsebenzi omusha',

# E-mail user
'emailuser'    => 'Thumela umlayezo lo msebenzisi',
'noemailtitle' => 'Akukho ikheli likaposi',
'emailsubject' => 'Indaba',
'emailmessage' => 'Umlayezo',
'emailsend'    => 'Thuma',
'emailsent'    => 'Umlayezo uthumwa',

# Watchlist
'watchlist'    => 'Uhlelo ubukelwa wami',
'watch'        => 'Bukela',
'unwatch'      => "Mus'ukubukela",
'notanarticle' => 'Akulona ikhasi elinakho okuqukethwe',

'enotif_newpagetext' => 'Lelikhasi liyasha.',

# Delete
'deletepage' => 'Sula ikhasi',
'confirm'    => 'Qinisekisa',
'exblank'    => 'ikhasi elize',

# Protect
'protectcomment' => 'Isizathu',

# Restrictions (nouns)
'restriction-edit' => 'Ukuhlela',
'restriction-move' => 'Sunduza',

# Undelete
'undeletecomment' => 'Khuluma:',

# Contributions
'contributions' => 'Amanikelo amsebenzisi',
'mycontris'     => 'Amanikelo ami',

# What links here
'isredirect' => 'Ikhasi silayela',

# Block/unblock
'blockip'            => 'Vimbela lo msebenzisi',
'ipbexpiry'          => 'Ukuphela',
'ipbreason'          => 'Isizathu',
'ipbsubmit'          => 'Vimbela lo msebenzisi',
'ipusubmit'          => 'Qeda isivimbelo lo msebenzisi',
'createaccountblock' => 'Ukudala kwekhawundi kuvimbelwa',
'proxyblocksuccess'  => 'Kuphelile.',

# Developer tools
'databasenotlocked' => 'Idatabheyisi alikhiyiwi.',

# Move page
'move-page-legend'        => 'Thuthisa ikhasi',
'movearticle'             => 'Thuthisa ikhasi',
'movenologin'             => 'Awungenile',
'movepagebtn'             => 'Thuthisa ikhasi',
'movedto'                 => 'Lithuthiselwe e',
'movereason'              => 'Isizathu',
'delete_and_move'         => 'Sula futhi sunduza',
'delete_and_move_confirm' => 'Yebo, sula ikhasi',

# Export
'export-submit' => 'Thekelisa',

# Namespace 8 related
'allmessagesname' => 'Igama',

# Thumbnails
'thumbnail-more' => 'Khulisa',
'filemissing'    => 'Ifayili lilahlekile',

# Special:Import
'import-interwiki-submit' => 'Ngenisa',

# Attribution
'others' => 'Abanye',

# Patrolling
'markaspatrolleddiff' => 'Dweba ukuthi lelikhasi liyagadwa',
'markaspatrolledtext' => 'Dweba ukuthi lelikhasi liyagadwa',
'markedaspatrolled'   => 'Dweba ukuthi lelikhasi liyagadwa',

# Special:NewFiles
'newimages' => 'Uhlelo lwamafayela amasha',
'noimages'  => 'Awuboni lutho.',
'ilsubmit'  => 'Sesha',

# Metadata
'metadata-expand'   => 'Bukisa imininingwane yonke',
'metadata-collapse' => 'Fihla imininingwane yonke',

# EXIF tags
'exif-orientation' => 'Ukuma okumaqondana nempumalanga',
'exif-artist'      => 'Umbhali',
'exif-sharpness'   => 'Ububukhali',

'exif-orientation-1' => 'Kuphelele',

'exif-meteringmode-5' => 'Umhlobiso',

'exif-lightsource-4'  => 'Umbani',
'exif-lightsource-11' => 'Umthunzi',

'exif-sensingmethod-1' => 'Akucaci',

'exif-scenecapturetype-0' => 'Izinga',
'exif-scenecapturetype-1' => 'Umfanekiso wesizwe',
'exif-scenecapturetype-2' => 'Umfanekiso womuntu',
'exif-scenecapturetype-3' => 'Imboniso ebusuku',

'exif-contrast-0' => 'Kuphelele',
'exif-contrast-1' => 'Kuntofontofo',
'exif-contrast-2' => 'Kulukhuni',

'exif-saturation-0' => 'Kuphelele',

'exif-sharpness-0' => 'Kuphelele',
'exif-sharpness-1' => 'Kuntofontofo',
'exif-sharpness-2' => 'Kulukhuni',

# 'all' in various places, this might be different for inflected languages
'recentchangesall' => 'Konke',

# E-mail address confirmation
'confirmemail'          => 'Qinisekisa ikheli likagesi',
'confirmemail_loggedin' => 'Ikheli likagesi lakho liqinisekiswa.',

# Delete conflict
'recreate' => 'Dala kabusha',

# action=purge
'confirm_purge_button' => 'Kulungile',

# Special:FilePath
'filepath-submit' => 'Hamba',

);
